@@ -3,14 +3,19 @@
 #' @author Richèl J.C. Bilderbeek
 #' @export
 #' @examples
-#' # Will stop if BEAST2 is not installed
-#' if (is_beast2_installed()) {
+#' if (beastier::is_on_ci() && is_beast2_installed()) {
+#'   beastier::remove_beaustier_folders()
+#'   beastier::check_empty_beaustier_folders()
+#'
 #'   bbt_self_test()
+#'
+#'   beastier::remove_beaustier_folders()
+#'   beastier::check_empty_beaustier_folders()
 #' }
 bbt_self_test <- function(
   beast2_options = beastier::create_beast2_options()
 ) {
-  testit::assert(beastier::is_beast2_installed())
+  testthat::expect_true(beastier::is_beast2_installed())
   inference_model <- beautier::create_test_inference_model()
   babette::bbt_run_from_model(
     fasta_filename = beautier::get_fasta_filename(),
