@@ -6,7 +6,10 @@
 #' @return nothing. Will produce a plot.
 #' @author Richèl J.C. Bilderbeek
 #' @examples
-#' if (is_beast2_installed()) {
+#' if (beastier::is_on_ci() && is_beast2_installed()) {
+#'   beastier::remove_beaustier_folders()
+#'   beastier::check_empty_beaustier_folders()
+#'
 #'   inference_model <- create_test_inference_model()
 #'   beast2_options <- create_beast2_options()
 #'
@@ -27,13 +30,15 @@
 #'     inference_model = inference_model,
 #'     beast2_options = beast2_options
 #'   )
+#'   beastier::remove_beaustier_folders()
+#'   beastier::check_empty_beaustier_folders()
 #' }
 #' @export
 plot_densitree <- function(
   phylos,
   ...
 ) {
-  if (class(phylos) != "multiPhylo") {
+  if (!inherits(phylos, "multiPhylo")) {
     stop("'phylos' must be of class 'multiPhylo'")
   }
   phangorn::densiTree(phylos, ...)
