@@ -4,6 +4,10 @@ knitr::opts_chunk$set(
   comment = "#>"
 )
 
+## ----check_empty_cache_at_start, include = FALSE------------------------------
+beastier::remove_beaustier_folders()
+beastier::check_empty_beaustier_folders()
+
 ## -----------------------------------------------------------------------------
 library(babette)
 library(testthat)
@@ -60,25 +64,37 @@ mcmc <- beautier::create_test_ns_mcmc()
 
 ## -----------------------------------------------------------------------------
 if (is_beast2_installed() && is_beast2_pkg_installed("NS")) {
+  inference_model <- create_inference_model(
+    site_model = beautier::create_jc69_site_model(),
+    mcmc = mcmc
+  )  
+  beast2_options <- create_beast2_options(
+    beast2_path = beastier::get_default_beast2_bin_path()
+  )
   out_jc69 <- bbt_run_from_model(
     fasta_filename = fasta_filename,
-    inference_model = create_inference_model(
-      site_model = beautier::create_jc69_site_model(),
-      mcmc = mcmc
-    ),
-    beast2_options = create_beast2_options(
-      beast2_path = beastier::get_default_beast2_bin_path()
-    )
+    inference_model = inference_model,
+    beast2_options = beast2_options
+  )
+  bbt_delete_temp_files(
+    inference_model = inference_model,
+    beast2_options = beast2_options
+  )
+  inference_model <- create_inference_model(
+    site_model = beautier::create_gtr_site_model(),
+    mcmc = mcmc
+  )
+  beast2_options <- create_beast2_options(
+    beast2_path = beastier::get_default_beast2_bin_path()
   )
   out_gtr <- bbt_run_from_model(
     fasta_filename = fasta_filename,
-    inference_model = create_inference_model(
-      site_model = beautier::create_gtr_site_model(),
-      mcmc = mcmc
-    ),
-    beast2_options = create_beast2_options(
-      beast2_path = beastier::get_default_beast2_bin_path()
-    )
+    inference_model = inference_model,
+    beast2_options = beast2_options
+  )
+  bbt_delete_temp_files(
+    inference_model = inference_model,
+    beast2_options = beast2_options
   )
 }
 
@@ -98,3 +114,7 @@ if (is_beast2_installed() && is_beast2_pkg_installed("NS")) {
   print(interpret_bayes_factor(bayes_factor))
 }
 
+## ----check_empty_cache_at_end, include = FALSE--------------------------------
+beastier::remove_beaustier_folders()
+beastier::check_empty_beaustier_folders()
+
